## Les philosophes antiques

Il est fascinant de voir à quel point les philosophes de l'Antiquité étaient 
évolués, et ce dans pratiquement tous les domaines. Il est non moins fascinant 
de se rendre compte à quel point nous avons régressé dans ces disciplines au fil 
des siècles - en grande partie à cause de la religion, mais aussi de nos valeurs 
sociales modernes - et il faudra attendre le vingtième siècle pour que les 
sciences s'affranchissent de certains dogmes qui limitaient leur avancée, avant 
que d'autres dogmes ne les prennent en otage...

Leurs hypothèses étaient, bien sûr, "maladroites", selon nos connaissances 
actuelles, plus de deux mille ans plus tard. Mais beaucoup d'entre elles étaient 
plus ou moins correctes. Les intuitions (ou même parfois les observations) des 
Grecs étaient justes, ou en tout cas, bien inspirées. Il faut dire que, 
idéalement situés, ils bénéficiaient d'échanges culturels importants avec les 
civilisations avoisinantes, en particulier avec l'Égypte qui avait déjà bâti ses 
pyramides (dont on ignore encore aujourd'hui les secrets de leur conception tant 
elle était précise), hôtesse de la ville d'Alexandrie, où Pythagore, Thalès et 
Euclide vinrent s'abreuver des connaissances locales, notamment en géométrie 
et en astronomie. En outre, par l'intermédiaire des peuples musulmans, mais dans 
une moindre mesure, le monde occidental d'alors échangeait également avec la 
Chine.

Par exemple, Démocrite[@contributeurs_wikipedia_democrite_2020] (460 - 370 av. 
J.-C.), doté d'une inextinguible soif de connaissances et donc d'une culture 
générale extraordinaire, devinait déjà l'existence de l'atome il y a près de 
deux mille quatre cents ans. Il croyait également en une cosmologie admettant 
qu'une infinité de mondes existent au sein d'un ou plusieurs univers, cosmologie 
déjà suggérée deux cents ans auparavant par Anaximandre
[@contributeurs_wikipedia_anaximandre_2020] (610 - 546 av. J.-C.), qui cherchait 
par ailleurs à expliquer l'origine des choses et les phénomènes météorologiques 
sans intervention divine. En outre, contemporain de Démocrite, c'est déjà vers 
360 av. J.-C. que Socrate postulait la sphéricité de la Terre dans le _Timée_
[@platon_timee_nodate] de Platon.

![_Image #8_: Le monde selon Anaximandre.](anaximandre-monde.png)

En ce temps-là, le monde connu était limité aux terres enveloppant la Mer 
Méditerranée (d'où son nom, le latin _mediterraneus_ signifiant "au milieu des 
terres") et la Mer Noire. Anaximandre était d'ailleurs considéré comme l'un des 
premiers cartographes. Il se figurait le monde "moderne" de l'époque, civilisé 
et évolué, comme un disque de terre entouré d'océan, et divisé en trois zones:

* L'Europe était délimitée par la Mer Méditerranée, la Mer Noire et le _Phase_ 
    (aujourd'hui nommé _Rioni_, principal fleuve à l'ouest de l'actuelle 
    Géorgie)
* La Lybie (l'actuel continent Africain), qui comprenait notamment l’Égypte
* L'Asie, séparée de la Lybie par le _Nil_ à l'est et de l'Europe par le _Phase_ 
    au nord-est

Dans cette représentation, Jérusalem se trouve près du centre du monde. Son 
histoire[@contributeurs_wikipedia_histoire_2021-1], complexe et peuplée de 
conquêtes successives, est trop riche pour que je l'aborde en détails ici. 
Notons simplement qu'au cours du premier siècle, c'est une ville prospère: issu 
de l'Empire Romain, Hérode le Grand y est au pouvoir, et rénove et étend le 
Second Temple de Jérusalem, où débutera la narration du _Nouveau Testament_ de 
la _Bible Chrétienne_.

Bien que la date et les circonstances exactes sont toujours sujettes à débat, on 
concède toutefois que c'est à cette période, vers le milieu du premier siècle, 
que le christianisme commença à rayonner tout autour de la Méditerranée
[@contributeurs_wikipedia_histoire_2021-2]. Son adoption est rapide et massive, 
grâce à la position géographique privilégiée de Jérusalem, accessible par des 
routes terrestres et maritimes déjà bien connues: depuis la puissante cité-état 
de Tyr, par la mer jusqu'à Milet, berceau de Thalès et d'Anaximandre, puis 
Troie, avant de rejoindre Athènes à l'ouest et Antioche à l'est. Tel fut le 
trajet de Paul de Tarse[@contributeurs_wikipedia_paul_2021], d'abord persécuteur 
des disciples de Jésus avant d'en devenir un apôtre auto-proclamé mais non 
reconnu, lors de ses voyages pour diffuser le christianisme. 

![_Image #9_: Le troisième voyage missionnaire de Paul de Tarse.](3eme-voyage-paul-de-tarse.png)

Les plus pauvres et les esclaves trouvent dans la religion chrétienne le 
réconfort de la foi. Elle leur apporte un soutient - y compris financier - rendu 
nécessaire par les inégalités sociales. Ils ne se sentaient pas touchés par les 
philosophes, mais l'ont été par la religion qui s'adressait directement à eux.

Au cours des siècles qui suivirent, le christianisme devint de plus en plus 
puissant. L'Empire Romain en fit sa religion officielle à la fin du quatrième 
siècle, et en 600, il s'étendra jusqu'en Angleterre. Les anciennes théories 
scientifiques tombèrent dans l'oubli au profit du dogme de la Création du monde 
par Dieu, et de la nature à la fois divine et humaine du Christ, créant de fait 
le clivage entre le Règne Humain et le Règne Animal. Un dogme qui persistera 
jusqu'à nos jours, et qui réprimera - souvent dans le sang - toute idée 
incompatible, telles que la sphéricité de la Terre, le monde héliocentrique, la 
parenté de l'Homme avec tout animal et surtout le singe, l'apparition et 
l'extinction d'espèces, etc.

Cette adoption est rapide et vigoureuse: l'empereur Justinien, qui "_se conçoit 
comme un empereur chrétien, messager de Dieu, chargé de faire de son empire 
terrestre l'équivalent du royaume céleste_"
[@contributeurs_wikipedia_justinien_2020], fait fermer les écoles philosophiques 
d'Athènes en 529 au cours de la _translatio studiorum_
[@contributeurs_wikipedia_translatio_2019]. Les philosophes héritiers de Platon 
et de Aristote sont contraints de se réfugier, notamment dans la Perse de 
Khosrô I^er^. C'est probablement en partie grâce à ce "transfert des études" que 
la philosophie aristotélicienne a pu survivre jusqu'à nos jours. Justinien sera 
également à l'origine d'un code qui porte son nom, "_obligeant notamment les 
païens à être baptisés_".

Toutefois, la culture ainsi perdue par l'occident chrétien sera récupérée et 
développée par l'orient musulman. Les centres intellectuels se trouvent 
désormais à Damas, puis Bagdad. Ce n'est que bien plus tard, lors de la 
renaissance intellectuelle du XII^ème^ siècle, que cette culture oubliée refera 
parler d'elle en Europe latine.